@@ -1,6 +1,6 @@
 /* Target-dependent code for the NDS32 architecture, for GDB.
 
-   Copyright (C) 2013-2025 Free Software Foundation, Inc.
+   Copyright (C) 2013-2026 Free Software Foundation, Inc.
    Contributed by Andes Technology Corporation.
 
    This file is part of GDB.
@@ -551,10 +551,9 @@ struct nds32_frame_cache
 static struct nds32_frame_cache *
 nds32_alloc_frame_cache (void)
 {
-  struct nds32_frame_cache *cache;
   int i;
 
-  cache = FRAME_OBSTACK_ZALLOC (struct nds32_frame_cache);
+  auto *cache = frame_obstack_zalloc<nds32_frame_cache> ();
 
   /* Initialize fp_offset to check if FP is set in prologue.  */
   cache->fp_offset = INVALID_OFFSET;
@@ -1975,7 +1974,7 @@ nds32_gdbarch_init (struct gdbarch_info info, struct gdbarch_list *arches)
     return best_arch->gdbarch;
 
   if (!tdesc_has_registers (tdesc))
-    tdesc = tdesc_nds32;
+    tdesc = tdesc_nds32.get ();
 
   tdesc_data = tdesc_data_alloc ();
 
@@ -2017,7 +2016,7 @@ nds32_gdbarch_init (struct gdbarch_info info, struct gdbarch_list *arches)
 
   /* Cache the register number of fs0.  */
   if (fpu_freg != -1)
-    tdep->fs0_regnum = user_reg_map_name_to_regnum (gdbarch, "fs0", -1);
+    tdep->fs0_regnum = user_reg_map_name_to_regnum (gdbarch, "fs0");
 
   /* Add NDS32 register aliases.  To avoid search in user register name space,
      user_reg_map_name_to_regnum is not used.  */
